@@ -601,7 +601,7 @@ get_mime_type_from_filename (GFile *file)
 	g_free (filename);
 
 	/* if a disk image is not compressed, 7z can handle it correctly */
-	if (mime_type && strcmp (mime_type, "application/x-raw-disk-image") == 0) {
+	if (mime_type && strcmp (mime_type, "application/vnd.efi.img") == 0) {
 		const char * real_type = get_mime_type_from_magic_numbers(file);
 		if (real_type
 			&& (strcmp (real_type, "application/gzip") == 0
@@ -1182,7 +1182,7 @@ load_local_archive (FrArchive  *archive,
 
 	fr_archive_connect_to_command (archive);
 	if (strcmp(mime_type, "compressed-disk-image") == 0) /* a virtual type */
-		archive->content_type = "application/x-raw-disk-image";
+		archive->content_type = "application/vnd.efi.img";
 	else
 		archive->content_type = mime_type;
 	if (! fr_command_is_capable_of (archive->command, FR_COMMAND_CAN_WRITE))
