@@ -345,7 +345,10 @@ fr_command_7z_add (FrCommand     *comm,
 	if (spd_support) fr_process_add_arg (comm->process, "-spd");
 	fr_process_add_arg (comm->process, "-bd");
 	fr_process_add_arg (comm->process, "-y");
+#ifndef USE_7Z
+	/* Unlike p7zip, 7zip does not support '-l'. Define USE_7Z to disable '-l'. */
 	fr_process_add_arg (comm->process, "-l");
+#endif
 	add_password_arg (comm, comm->password, FALSE);
 	if ((comm->password != NULL)
 	    && (*comm->password != 0)
@@ -582,8 +585,8 @@ fr_command_7z_handle_error (FrCommand   *comm,
 const char *sevenz_mime_types[] = { "application/x-7z-compressed",
 				    "application/x-arj",
 				    "application/vnd.ms-cab-compressed",
-				    "application/x-cd-image",
-				    "application/x-raw-disk-image",
+				    "application/vnd.efi.iso",
+				    "application/vnd.efi.img",
 				    /*"application/x-cbr",*/
 				    "application/x-cbz",
 				    "application/x-ms-dos-executable",
